pub struct ExecutableName { /* private fields */ }Expand description
A validated executable or binary name.
Implementations
Sourceimpl ExecutableName
impl ExecutableName
Sourcepub fn new(name: impl Into<String>) -> Result<ExecutableName, CommandNameError>
pub fn new(name: impl Into<String>) -> Result<ExecutableName, CommandNameError>
Creates a validated executable name.
Errors
Returns CommandNameError when name is not a valid command name.
Sourcepub fn from_path(
path: impl AsRef<Path>,
) -> Result<ExecutableName, CommandNameError>
pub fn from_path( path: impl AsRef<Path>, ) -> Result<ExecutableName, CommandNameError>
Extracts a validated executable name from a path.
Errors
Returns CommandNameError when the path has no file name, the file name is not Unicode,
or the file name is not a valid command name.
Sourcepub const fn command_name(&self) -> &CommandName
pub const fn command_name(&self) -> &CommandName
Returns the executable name as a command name.
Sourcepub fn display_name(&self) -> &str
pub fn display_name(&self) -> &str
Returns the display name.
Sourcepub fn into_command_name(self) -> CommandName
pub fn into_command_name(self) -> CommandName
Returns the owned executable name.